# Dynamic Causal Modelling of COVID-19

Preprints on arXiv:
* [Dynamic Causal Modelling of COVID-19](https://arxiv.org/abs/2004.04463)
* [Second waves, social distancing, and the spread of COVID-19 across America](https://arxiv.org/abs/2004.13017)
* [Tracking and tracing in the UK: a dynamic causal modelling study](https://arxiv.org/abs/2005.07994)
* [Effective immunity and second waves: a dynamic causal modelling study](https://arxiv.org/abs/2006.09429)
* [Dynamic causal modelling of mitigated epidemiological outcomes](https://arxiv.org/abs/2011.12400)

See also: https://www.fil.ion.ucl.ac.uk/spm/covid-19/

## SPM Software
```
Statistical Parametric Mapping
https://www.fil.ion.ucl.ac.uk/spm/
Copyright 2020 Wellcome Centre for Human Neuroimaging
```

See `spm12/README.md` for details.

This repository contains a subset of the SPM12 functions required to reproduce the analyses of the technical report (based on SPM12 r8007). From the MATLAB or Octave prompt, type:

```
>> addpath(fullfile(pwd, 'spm12'));
>> addpath(fullfile(pwd, 'data'));
>> DEM_COVID_UK
>> DEM_COVID_I
>> DEM_COVID_T
>> DEM_COVID_X
>> DEM_COVID
```

For a complete version of the SPM12 software and future versions, please check: https://www.fil.ion.ucl.ac.uk/spm/covid-19/

If you use GNU Octave, you also need to use tailored versions of `importdata.m` in order to read the CSV files correctly.
For `DATA_COVID_JHU.m`, copy the following at the end of the file:
```
function data = importdata(filename)

S    = fileread(filename);
ncol = numel(find(strtok(S,sprintf('\n'))==',')) + 1;
S    = textscan(S,'%q','Delimiter',',');
S    = reshape(S{1},ncol,[])';
if size(S,2)>2
    % time_series_covid19_*_global.csv
    % first row is header and first two columns are state/country
    data.data = cellfun(@(x)str2double(x),S(2:end,3:end));
    data.textdata = S;
    [data.textdata{2:end,3:end}] = deal('');
else
    % population.csv
    data.data = cellfun(@(x)str2double(x),S(:,2));
    data.textdata = S(:,1);
end
```
For `DATA_COVID_US.m`, copy the following at the end of the file:
```
function data = importdata(filename,varargin)

S    = fileread(filename);
ncol = numel(find(strtok(S,sprintf('\n'))==',')) + 1;
S    = textscan(S,'%q','Delimiter',',');
S    = reshape(S{1},ncol,[])';

% first row is header and first 11 columns are metadata
data.data     = cellfun(@(x)str2double(x),S(2:end,12:end));
data.textdata = S(:,1:11);
```
An adapted version of this will also be required on Octave for `DATA_COVID_UK.m`.

## COVID-19 Data Repository from Johns Hopkins University

```
COVID-19 Data Repository by the Center for Systems Science and Engineering (CSSE) at Johns Hopkins University
https://github.com/CSSEGISandData/COVID-19
Copyright 2020 Johns Hopkins University, all rights reserved
```

## Coronavirus (COVID-19) UK Historical Data

```
By Tom White: http://tom-e-white.com/covid-19-uk-data/
https://github.com/tomwhite/covid-19-uk-data
This is free and unencumbered software released into the public domain.
```

See `data/README.md` for details.
